pub struct __StaticInitGeneratorFor_DOC;Trait Implementations
Sourceimpl Generator<Schema> for __StaticInitGeneratorFor_DOC
Available on Windows, or (Android or DragonFly BSD or Emscripten or FreeBSD or Fuchsia or Haiku or illumos or L4Re or Linux or NetBSD or OpenBSD or Redox OS or Solaris or VxWorks), or (iOS or macOS) only.
impl Generator<Schema> for __StaticInitGeneratorFor_DOC
Available on Windows, or (Android or DragonFly BSD or Emscripten or FreeBSD or Fuchsia or Haiku or illumos or L4Re or Linux or NetBSD or OpenBSD or Redox OS or Solaris or VxWorks), or (iOS or macOS) only.
Sourceimpl GeneratorTolerance for __StaticInitGeneratorFor_DOC
Available on Windows, or (Android or DragonFly BSD or Emscripten or FreeBSD or Fuchsia or Haiku or illumos or L4Re or Linux or NetBSD or OpenBSD or Redox OS or Solaris or VxWorks), or (iOS or macOS) only.
impl GeneratorTolerance for __StaticInitGeneratorFor_DOC
Available on Windows, or (Android or DragonFly BSD or Emscripten or FreeBSD or Fuchsia or Haiku or illumos or L4Re or Linux or NetBSD or OpenBSD or Redox OS or Solaris or VxWorks), or (iOS or macOS) only.
const INIT_FAILURE: bool = true
const FINAL_REGISTRATION_FAILURE: bool = false